@@ -12,15 +12,22 @@ class SelfGroupMessage(GroupMessageEvent):
 
 class MessageGot(BaseModel):
     message_id: int
+    """消息id"""
     real_id: int
+    """消息真实id"""
     sender: Sender
+    """发送者"""
     time: int
+    """发送时间"""
     message: Message
+    """消息内容"""
     raw_message: str
+    """原始消息内容"""
 
 
 class GroupMessageGot(MessageGot):
     group_id: int
+    """群号"""
     message_type: Literal["group"]
 
 
